@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Rinci;
 
-our $DATE = '2015-12-25'; # DATE
-our $VERSION = '0.52'; # VERSION
+our $DATE = '2016-01-21'; # DATE
+our $VERSION = '0.53'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -104,8 +104,14 @@ sub _process_module {
         my %opts;
         # position
         if ($sectname eq 'FUNCTIONS') {
-            $opts{after_section} = ['DESCRIPTION'];
-            $opts{before_section} = ['HOMEPAGE'];
+            $opts{after_section} = [
+                'DESCRIPTION',
+            ];
+            # make sure we don't put it too below
+            $opts{before_section} = [
+                'SEE ALSO',
+                'HOMEPAGE',
+            ];
         }
 
         $self->add_text_to_section($document, $sectcontent, $sectname, \%opts);
@@ -335,8 +341,20 @@ sub _process_script {
         }
         last unless @content;
 
-        $self->add_text_to_section($document, join('', @content), 'SYNOPSIS',
-                                   {ignore=>1, after_section=>['VERSION','NAME']});
+        $self->add_text_to_section(
+            $document, join('', @content), 'SYNOPSIS',
+            {
+                ignore=>1,
+                after_section => [
+                    'VERSION',
+                    'NAME',
+                ],
+                # just to make we don't put it too below
+                before_section => [
+                    'DESCRIPTION',
+                    'SEE ALSO',
+                ],
+            });
         $modified++;
     }
 
@@ -350,8 +368,20 @@ sub _process_script {
             Markdown::To::POD::markdown_to_pod($metas{''}{description});
         push @content, "\n\n";
 
-        $self->add_text_to_section($document, join('', @content), 'DESCRIPTION',
-                                   {ignore=>1, after_section=>['SYNOPSIS','VERSION','NAME']});
+        $self->add_text_to_section(
+            $document, join('', @content), 'DESCRIPTION',
+            {
+                ignore=>1,
+                after_section=>[
+                    'SYNOPSIS',
+                    'VERSION',
+                    'NAME',
+                ],
+                # make sure we don't put it too below
+                before_section => [
+                    'SEE ALSO',
+                ],
+            });
         $modified++;
     }
 
@@ -378,8 +408,20 @@ sub _process_script {
             }
         }
 
-        $self->add_text_to_section($document, join('', @content), 'SUBCOMMANDS',
-                                   {ignore=>1, after_section=>['DESCRIPTION','SYNOPSIS']});
+        $self->add_text_to_section(
+            $document, join('', @content), 'SUBCOMMANDS',
+            {
+                ignore=>1,
+                after_section => [
+                    'DESCRIPTION',
+                    'SYNOPSIS',
+                ],
+                # make sure we don't put it too below
+                before_section => [
+                    'OPTIONS',
+                    'SEE ALSO',
+                ],
+            });
         $modified++;
     }
 
@@ -473,8 +515,24 @@ sub _process_script {
             }
         }
 
-        $self->add_text_to_section($document, join('', @content), 'OPTIONS',
-                                   {ignore=>1, after_section=>['SUBCOMMANDS','DESCRIPTION']});
+        $self->add_text_to_section(
+            $document, join('', @content), 'OPTIONS',
+            {
+                ignore => 1,
+                after_section => [
+                    'SUBCOMMANDS',
+                    'DESCRIPTION',
+                ],
+                # make sure we don't put it too below
+                before_section => [
+                    'COMPLETION',
+                    'ENVIRONMENT',
+                    'CONFIGURATION FILE',
+                    'HOMEPAGE',
+                    'SEE ALSO',
+                    'AUTHOR',
+                ],
+            });
         $modified++;
     }
 
@@ -502,8 +560,18 @@ sub _process_script {
         push @content, "=head2 ", $env_name, " => str\n\n";
         push @content, "Specify additional command-line options\n\n";
 
-        $self->add_text_to_section($document, join('', @content), 'ENVIRONMENT',
-                                   {before_section=>'HOMEPAGE'});
+        $self->add_text_to_section(
+            $document, join('', @content), 'ENVIRONMENT',
+            {
+                after_section => [
+                    'OPTIONS',
+                ],
+                # make sure we don't put it too below
+                before_section => [
+                    'HOMEPAGE',
+                    'SEE ALSO',
+                ],
+            });
         $modified++;
     }
 
@@ -520,30 +588,48 @@ sub _process_script {
 
         last unless $cli->read_config;
 
-        my $config_filename;
+        my $config_filenames = [];
         my $config_dirs;
+        my @files;
 
         # FILES section
         {
             my @content;
-            $config_filename = $cli->config_filename //
-                ($cli->program_name ? $cli->program_name . ".conf" : undef) //
-                $prog . ".conf";
+            if ($cli->config_filename) {
+                push @$config_filenames,
+                    ref($cli->config_filename) eq 'ARRAY' ?
+                    @{ $cli->config_filename } : $cli->config_filename;
+            } elsif ($cli->program_name) {
+                push @$config_filenames, $cli->program_name . ".conf";
+            } else {
+                push @$config_filenames, $prog . ".conf";
+            }
             $config_dirs = $cli->{config_dirs} // ['~/.config', '~', '/etc'];
 
-            for my $config_dir (@{$config_dirs}) {
-                push @content, "$config_dir/$config_filename\n\n";
+            for my $config_dir (@$config_dirs) {
+                for my $config_filename (@$config_filenames) {
+                    my $p = "$config_dir/$config_filename";
+                    push @files, $p;
+                    push @content, "$p\n\n";
+                }
             }
 
-            $self->add_text_to_section($document, join('', @content), 'FILES',
-                                       {after_section=>'ENVIRONMENT'});
+            $self->add_text_to_section(
+                $document, join('', @content), 'FILES',
+                {
+                    after_section => 'ENVIRONMENT',
+                    # make sure we don't put it too below
+                    before_section => [
+                        'SEE ALSO',
+                    ],
+                });
         }
 
         # CONFIGURATION FILE section
         {
             my @content;
 
-            my @files_list = map {"C<$_/$config_filename>"} @$config_dirs;
+            my @files_list = @files;
             if (@files_list > 2) {
                 my $is_last = 1;
                 for (reverse 1..@files_list-1) {
@@ -606,8 +692,13 @@ sub _process_script {
                 push @content, "\n";
             }
 
-            $self->add_text_to_section($document, join('', @content), 'CONFIGURATION FILE',
-                                       {before_section=>'FILES'});
+            $self->add_text_to_section(
+                $document, join('', @content), 'CONFIGURATION FILE',
+                {
+                    before_section=>[
+                        'FILES',
+                    ],
+                });
         }
 
         $modified++;
@@ -667,7 +758,7 @@ Pod::Weaver::Plugin::Rinci - Insert stuffs to POD from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.52 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2015-12-25.
+This document describes version 0.53 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2016-01-21.
 
 =head1 SYNOPSIS
 
@@ -760,10 +851,6 @@ the script.
 
 =for Pod::Coverage weave_section
 
-=head1 SEE ALSO
-
-L<Pod::Weaver>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Pod-Weaver-Plugin-Rinci>.
@@ -780,13 +867,17 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Pod::Weaver>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
